@@ -19,7 +19,7 @@ use Types::Standard -types;
 
 use namespace::autoclean;
 
-our $VERSION = 'v0.1.2';
+our $VERSION = 'v0.1.3';
 
 
 sub mvp_multivalue_args { qw/ add remove / }
@@ -59,10 +59,12 @@ sub gather_files {
     $mms->add( '\.build/' );
     $mms->add( $zilla->name . '-.*/' );
     $mms->add( $zilla->name . '-.*\.tar\.gz' );
+    $mms->add( '\.mailmap$' );
 
     $mms->remove('^MANIFEST\.SKIP$');
     $mms->remove('^dist.ini$');
     $mms->remove('^weaver.ini$');
+    $mms->remove('^xt/');
 
     $mms->add('cpanfile\.snapshot$') if any { $_->name eq 'cpanfile' } @files;
     $mms->add('_alien/') if any { $_->name eq 'alienfile' } @files;
@@ -104,7 +106,14 @@ Dist::Zilla::Plugin::Generate::ManifestSkip - generate a MANIFEST.SKIP file for
 
 =head1 VERSION
 
-version v0.1.2
+version v0.1.3
+
+=head1 SYNOPSIS
+
+In your F<dist.ini> file:
+
+  [Generate::ManifestSkip]
+  :version = v0.1.2
 
 =head1 DESCRIPTION
 
@@ -127,6 +136,8 @@ By defaut, the following files are added to the skipfile:
 
 =item C<\.build/>
 
+=item C<\.mailmap$>
+
 =item C<{$dist_name}-.*/>
 
 =item C<{$dist_name}-.*\.tar\.gz>
@@ -155,6 +166,8 @@ By default, the following files are already removed from the skipfile:
 
 =item C<^weaver\.ini$>
 
+=item C<^xt/>
+
 =back
 
 If you want them to be excluded from your distribution, then specify
